from .__about__ import (
    __version__,
    __title__,
    __summary__
)

from .singleton import (  # noqa: F401
    PySingleton,
    PyMemoized
)

__all__ = [
    "__version__",
    "__title__",
    "__summary__"
]
